@@ -29,6 +29,26 @@
 #include <config.h>
 #endif
 
+/**
+ * SECTION:glade-fixed
+ * @Short_Description: An object wrapper for free-form placement container widgets.
+ *
+ * #GladeFixed is a specialized #GladeWidget to handle free-form child
+ * placements in containers that support this, it is designed with properties
+ * and signals with flexable integration in mind.
+ *
+ * If you set the x-prop/y-prop/width-prop/height-prop properties and
+ * leave the signals alone, #GladeFixed will assume you are like a 
+ * GtkFixed/GtkLayout widget and will use pixel counts as units for
+ * these properties.
+ *
+ * If you handle the configure-child/configure-end[/configure-begin] signals
+ * and dont let them propagate to the GladeFixed, then the x-prop/y-prop/width-prop/height-prop
+ * properties will be completely ignored and it is up to the implementor to play
+ * with whatever child packing properties are available to make a closest match
+ * for the values passed to configure-child via the #GdkRectangle.
+ */
+
 #include <glib-object.h>
 #include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
@@ -83,6 +103,7 @@ glade_fixed_get_operation (GtkWidget       *widget,
 			   gint             y)
 {
 	GladeCursorType operation = GLADE_CURSOR_DRAG;
+	GtkAllocation allocation;
 
 #if 0
 	g_print ("%s called (width %d height %d x %d y %d)\n",
@@ -91,31 +112,32 @@ glade_fixed_get_operation (GtkWidget       *widget,
 		 widget->allocation.height, x, y);
 #endif
 
+	gtk_widget_get_allocation (widget, &allocation);
 	if (x < GRAB_BORDER_WIDTH) {
 		if (y < GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_TOP_LEFT;
-		else if (y > widget->allocation.height - GRAB_BORDER_WIDTH)
+		else if (y > allocation.height - GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_BOTTOM_LEFT;
 		else
 			operation = GLADE_CURSOR_RESIZE_LEFT;
-	} else if (x > widget->allocation.width - GRAB_BORDER_WIDTH) {
+	} else if (x > allocation.width - GRAB_BORDER_WIDTH) {
 		if (y < GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_TOP_RIGHT;
-		else if (y > widget->allocation.height - GRAB_BORDER_WIDTH)
+		else if (y > allocation.height - GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_BOTTOM_RIGHT;
 		else
 			operation = GLADE_CURSOR_RESIZE_RIGHT;
 	} else if (y < GRAB_BORDER_WIDTH) {
 		if (x < GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_TOP_LEFT;
-		else if (x > widget->allocation.width - GRAB_BORDER_WIDTH)
+		else if (x > allocation.width - GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_TOP_RIGHT;
 		else
 			operation = GLADE_CURSOR_RESIZE_TOP;
-	} else if (y > widget->allocation.height - GRAB_BORDER_WIDTH) {
+	} else if (y > allocation.height - GRAB_BORDER_WIDTH) {
 		if (x < GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_BOTTOM_LEFT;
-		else if (x > widget->allocation.width - GRAB_BORDER_WIDTH)
+		else if (x > allocation.width - GRAB_BORDER_WIDTH)
 			operation = GLADE_CURSOR_RESIZE_BOTTOM_RIGHT;
 		else
 			operation = GLADE_CURSOR_RESIZE_BOTTOM;
@@ -127,6 +149,8 @@ static void
 glade_fixed_save_state (GladeFixed  *fixed,
 			GladeWidget *child)
 {
+	GtkAllocation allocation;
+
 	gtk_widget_get_pointer (GTK_WIDGET (GLADE_WIDGET (fixed)->object), 
 				&(GLADE_FIXED (fixed)->pointer_x_origin), 
 				&(GLADE_FIXED (fixed)->pointer_y_origin));
@@ -137,8 +161,9 @@ glade_fixed_save_state (GladeFixed  *fixed,
 					  &(fixed->child_x_origin), 
 					  &(fixed->child_y_origin));
 
-	fixed->child_width_origin  = GTK_WIDGET (child->object)->allocation.width;
-	fixed->child_height_origin = GTK_WIDGET (child->object)->allocation.height;
+	gtk_widget_get_allocation (GTK_WIDGET (child->object), &allocation);
+	fixed->child_width_origin  = allocation.width;
+	fixed->child_height_origin = allocation.height;
 
 	fixed->pointer_x_child_origin = 
 		fixed->pointer_x_origin - fixed->child_x_origin;
@@ -156,12 +181,14 @@ glade_fixed_filter_event (GladeFixed *fixed,
 			  gint        top,
 			  gint        bottom)
 {
+	GtkAllocation allocation;
 	gint cont_width, cont_height;
 
 	g_return_if_fail (x && y);
 
-	cont_width  = GTK_WIDGET (GLADE_WIDGET (fixed)->object)->allocation.width;
-	cont_height = GTK_WIDGET (GLADE_WIDGET (fixed)->object)->allocation.height;
+	gtk_widget_get_allocation (GTK_WIDGET (GLADE_WIDGET (fixed)->object), &allocation);
+	cont_width  = allocation.width;
+	cont_height = allocation.height;
 
 	/* Clip out mouse events that are outside the window.
 	 */
@@ -218,6 +245,7 @@ glade_fixed_handle_swindow (GladeFixed   *fixed,
 	GtkWidget     *fixed_widget = GTK_WIDGET (GLADE_WIDGET (fixed)->object);
 	GtkWidget     *swindow = NULL, *swindow_child = NULL;
 	GtkAdjustment *hadj, *vadj;
+	GtkAllocation  child_allocation;
 	gint           x, y;
 
 	swindow_child = swindow = fixed_widget;
@@ -226,7 +254,7 @@ glade_fixed_handle_swindow (GladeFixed   *fixed,
 		if (!GTK_IS_VIEWPORT (swindow))
 			swindow_child = swindow;
 
-		swindow = swindow->parent;
+		swindow = gtk_widget_get_parent (swindow);
 	}
 
 	if (swindow)
@@ -236,15 +264,16 @@ glade_fixed_handle_swindow (GladeFixed   *fixed,
 		 */
 		hadj = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (swindow));
 		vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (swindow));
+		gtk_widget_get_allocation (swindow_child, &child_allocation);
 
 		g_object_set (G_OBJECT (hadj),
 			      "lower", 0.0F,
-			      "upper", (gdouble) swindow_child->allocation.width + 0.0,
+			      "upper", (gdouble) child_allocation.width + 0.0,
 			      NULL);
 
 		g_object_set (G_OBJECT (vadj),
 			      "lower", 0.0F,
-			      "upper", (gdouble) swindow_child->allocation.height + 0.0,
+			      "upper", (gdouble) child_allocation.height + 0.0,
 			      NULL);
 
 		gtk_widget_translate_coordinates (fixed_widget,
@@ -511,6 +540,7 @@ glade_fixed_handle_child_event (GladeFixed  *fixed,
 {
 	GladeCursorType  operation;
 	GdkModifierType  event_state = 0;
+	GladePointerMode pointer_mode;
 	GtkWidget       *fixed_widget, *child_widget;
 	gint             fixed_x, fixed_y, child_x, child_y;
 	gboolean         handled = FALSE, sig_handled;
@@ -518,6 +548,8 @@ glade_fixed_handle_child_event (GladeFixed  *fixed,
 	fixed_widget = GTK_WIDGET (GLADE_WIDGET (fixed)->object);
 	child_widget = GTK_WIDGET (child->object);
 
+	pointer_mode = glade_app_get_pointer_mode ();
+
 	/* when widget->window points to a parent window, these calculations
 	 * would be wrong if we based them on the GTK_WIDGET (fixed)->window,
 	 * so we must always consult the event widget's window
@@ -545,10 +577,11 @@ glade_fixed_handle_child_event (GladeFixed  *fixed,
 	case GDK_MOTION_NOTIFY:
 		if (fixed->configuring == NULL)
 		{
-			if (event_state & GDK_SHIFT_MASK)
+			if ((event_state & GDK_SHIFT_MASK) ||
+			    pointer_mode == GLADE_POINTER_DRAG_RESIZE)
 				glade_cursor_set (((GdkEventAny *)event)->window, 
 						  operation);
-			else
+			else if (pointer_mode == GLADE_POINTER_SELECT)
 				glade_cursor_set (((GdkEventAny *)event)->window, 
 						  GLADE_CURSOR_SELECTOR);
 
@@ -572,13 +605,15 @@ glade_fixed_handle_child_event (GladeFixed  *fixed,
 			handled = TRUE;
 		}
 
-		gdk_window_get_pointer (GTK_WIDGET (child->object)->window, NULL, NULL, NULL);
+		gdk_window_get_pointer (gtk_widget_get_window (GTK_WIDGET (child->object)), NULL, NULL, NULL);
 		break;
 	case GDK_BUTTON_PRESS:
 		/* We cant rely on GDK_BUTTON1_MASK since event->state isnt yet updated
 		 * by the current event itself 
 		 */
-		if (((GdkEventButton *)event)->button == 1 && (event_state & GDK_SHIFT_MASK))
+		if (((GdkEventButton *)event)->button == 1 && 
+		    ((event_state & GDK_SHIFT_MASK) ||
+		     pointer_mode == GLADE_POINTER_DRAG_RESIZE))
 		{
 			fixed->configuring = child;
 			/* Save widget allocation and pointer pos */
@@ -598,7 +633,8 @@ glade_fixed_handle_child_event (GladeFixed  *fixed,
 		if (((GdkEventButton *)event)->button == 1 && fixed->configuring)
 		{
 
-			if (event_state & GDK_SHIFT_MASK)
+			if ((event_state & GDK_SHIFT_MASK) ||
+			    pointer_mode == GLADE_POINTER_DRAG_RESIZE)
 				glade_cursor_set (((GdkEventAny *)event)->window,
 						  operation);
 			else
@@ -639,7 +675,7 @@ glade_fixed_child_event (GladeWidget *gwidget,
 	 * the palette.
 	 */
 	if (GLADE_IS_FIXED (gwidget) &&
-	    glade_palette_get_current_item (glade_app_get_palette ()) != NULL)
+	    glade_app_get_pointer_mode() == GLADE_POINTER_ADD_WIDGET)
 	{
 		glade_cursor_set (((GdkEventAny *)event)->window, 
 				  GLADE_CURSOR_ADD_WIDGET);
@@ -659,9 +695,10 @@ glade_fixed_add_child_impl (GladeWidget *gwidget_fixed,
 			    GladeWidget *child,
 			    gboolean     at_mouse)
 {
-	GladeFixed   *fixed = GLADE_FIXED (gwidget_fixed);
-	GdkRectangle  rect;
-	gboolean      handled;
+	GladeFixed    *fixed = GLADE_FIXED (gwidget_fixed);
+	GtkAllocation  allocation;
+	GdkRectangle   rect;
+	gboolean       handled;
 
 	g_return_if_fail (GLADE_IS_FIXED (fixed));
 	g_return_if_fail (GLADE_IS_WIDGET (child));
@@ -669,7 +706,11 @@ glade_fixed_add_child_impl (GladeWidget *gwidget_fixed,
 	/* Chain up for the basic parenting */
 	GLADE_WIDGET_CLASS (parent_class)->add_child
 		(GLADE_WIDGET (fixed), child, at_mouse);
-	
+
+	/* We only operate on widgets here */
+	if (!GTK_IS_WIDGET (child->object))
+		return;
+		
 	gtk_widget_add_events (GTK_WIDGET (child->object),
 			       GDK_POINTER_MOTION_MASK      |
 			       GDK_POINTER_MOTION_HINT_MASK |
@@ -694,10 +735,11 @@ glade_fixed_add_child_impl (GladeWidget *gwidget_fixed,
 	} 
 	else if (at_mouse)
 	{
+		gtk_widget_get_allocation (GTK_WIDGET (child->object), &allocation);
 		rect.x      = fixed->mouse_x;
 		rect.y      = fixed->mouse_y;
-		rect.width  = GTK_WIDGET (child->object)->allocation.width;
-		rect.height = GTK_WIDGET (child->object)->allocation.height;
+		rect.width  = allocation.width;
+		rect.height = allocation.height;
 
 		if (rect.width < CHILD_WIDTH_DEF)
 			rect.width = CHILD_WIDTH_DEF;
@@ -804,15 +846,15 @@ glade_fixed_event (GladeWidget *gwidget_fixed,
 		}
 		break;
 	case GDK_MOTION_NOTIFY:
-		if (adaptor != NULL)
+		if (glade_app_get_pointer_mode() == GLADE_POINTER_ADD_WIDGET)
 		{
 			glade_cursor_set (((GdkEventAny *)event)->window, 
 					  GLADE_CURSOR_ADD_WIDGET);
 
 			handled = TRUE;
 		}
-		/* XXX I dont think this line is needed */
-		else if (GLADE_IS_FIXED (gwidget_fixed->parent) == FALSE)
+		else if (GLADE_IS_FIXED (gwidget_fixed->parent) == FALSE &&
+			 glade_app_get_pointer_mode() == GLADE_POINTER_SELECT)
 			glade_cursor_set (((GdkEventAny *)event)->window,
 					  GLADE_CURSOR_SELECTOR);
 		break;
