@@ -25,6 +25,7 @@ G_BEGIN_DECLS
 #define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
 #define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
 #define g_marshal_value_peek_object(v)   g_value_get_object (v)
+#define g_marshal_value_peek_variant(v)  g_value_get_variant (v)
 #else /* !G_ENABLE_DEBUG */
 /* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
  *          Do not access GValues directly in your code. Instead, use the
@@ -48,6 +49,7 @@ G_BEGIN_DECLS
 #define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
 #define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
 #define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
+#define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
 
@@ -150,7 +152,50 @@ glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
 /* VOID:STRING (./glade-marshallers.list:5) */
 #define glade_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:OBJECT,OBJECT (./glade-marshallers.list:6) */
+/* VOID:INT,INT (./glade-marshallers.list:6) */
+extern void glade_marshal_VOID__INT_INT (GClosure     *closure,
+                                         GValue       *return_value,
+                                         guint         n_param_values,
+                                         const GValue *param_values,
+                                         gpointer      invocation_hint,
+                                         gpointer      marshal_data);
+void
+glade_marshal_VOID__INT_INT (GClosure     *closure,
+                             GValue       *return_value G_GNUC_UNUSED,
+                             guint         n_param_values,
+                             const GValue *param_values,
+                             gpointer      invocation_hint G_GNUC_UNUSED,
+                             gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
+                                              gint         arg_1,
+                                              gint         arg_2,
+                                              gpointer     data2);
+  register GMarshalFunc_VOID__INT_INT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT_INT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_int (param_values + 1),
+            g_marshal_value_peek_int (param_values + 2),
+            data2);
+}
+
+/* VOID:OBJECT,OBJECT (./glade-marshallers.list:7) */
 extern void glade_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -193,7 +238,7 @@ glade_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOOLEAN (./glade-marshallers.list:7) */
+/* VOID:OBJECT,BOOLEAN (./glade-marshallers.list:8) */
 extern void glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -236,7 +281,7 @@ glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (./glade-marshallers.list:8) */
+/* VOID:STRING,STRING,STRING (./glade-marshallers.list:9) */
 extern void glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -281,7 +326,7 @@ glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* OBJECT:POINTER (./glade-marshallers.list:9) */
+/* OBJECT:POINTER (./glade-marshallers.list:10) */
 extern void glade_marshal_OBJECT__POINTER (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -326,7 +371,7 @@ glade_marshal_OBJECT__POINTER (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:OBJECT,UINT (./glade-marshallers.list:10) */
+/* OBJECT:OBJECT,UINT (./glade-marshallers.list:11) */
 extern void glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -373,7 +418,7 @@ glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* BOOLEAN:STRING (./glade-marshallers.list:11) */
+/* BOOLEAN:STRING (./glade-marshallers.list:12) */
 extern void glade_marshal_BOOLEAN__STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -418,7 +463,7 @@ glade_marshal_BOOLEAN__STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOXED (./glade-marshallers.list:12) */
+/* BOOLEAN:BOXED (./glade-marshallers.list:13) */
 extern void glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -463,7 +508,7 @@ glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (./glade-marshallers.list:13) */
+/* BOOLEAN:OBJECT (./glade-marshallers.list:14) */
 extern void glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -508,7 +553,7 @@ glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOXED (./glade-marshallers.list:14) */
+/* BOOLEAN:OBJECT,BOXED (./glade-marshallers.list:15) */
 extern void glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -555,7 +600,7 @@ glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,POINTER (./glade-marshallers.list:15) */
+/* BOOLEAN:OBJECT,POINTER (./glade-marshallers.list:16) */
 extern void glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -602,7 +647,7 @@ glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOOLEAN (./glade-marshallers.list:16) */
+/* BOOLEAN:OBJECT,BOOLEAN (./glade-marshallers.list:17) */
 extern void glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -649,7 +694,7 @@ glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,UINT (./glade-marshallers.list:17) */
+/* BOOLEAN:OBJECT,UINT (./glade-marshallers.list:18) */
 extern void glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -696,7 +741,7 @@ glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT (./glade-marshallers.list:18) */
+/* BOOLEAN:OBJECT,OBJECT (./glade-marshallers.list:19) */
 extern void glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -743,7 +788,7 @@ glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING (./glade-marshallers.list:19) */
+/* BOOLEAN:OBJECT,STRING (./glade-marshallers.list:20) */
 extern void glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -790,7 +835,7 @@ glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING,STRING,BOXED (./glade-marshallers.list:20) */
+/* BOOLEAN:STRING,STRING,STRING,BOXED (./glade-marshallers.list:21) */
 extern void glade_marshal_BOOLEAN__STRING_STRING_STRING_BOXED (GClosure     *closure,
                                                                GValue       *return_value,
                                                                guint         n_param_values,
@@ -841,7 +886,7 @@ glade_marshal_BOOLEAN__STRING_STRING_STRING_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,BOXED,OBJECT (./glade-marshallers.list:21) */
+/* BOOLEAN:STRING,BOXED,OBJECT (./glade-marshallers.list:22) */
 extern void glade_marshal_BOOLEAN__STRING_BOXED_OBJECT (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -890,7 +935,7 @@ glade_marshal_BOOLEAN__STRING_BOXED_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* STRING:OBJECT (./glade-marshallers.list:22) */
+/* STRING:OBJECT (./glade-marshallers.list:23) */
 extern void glade_marshal_STRING__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -935,7 +980,7 @@ glade_marshal_STRING__OBJECT (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* INT:OBJECT,BOXED (./glade-marshallers.list:23) */
+/* INT:OBJECT,BOXED (./glade-marshallers.list:24) */
 extern void glade_marshal_INT__OBJECT_BOXED (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
