@@ -46,6 +46,7 @@ typedef enum
 	GLADE_PROJECT_MODEL_COLUMN_NAME,
 	GLADE_PROJECT_MODEL_COLUMN_TYPE_NAME,
 	GLADE_PROJECT_MODEL_COLUMN_OBJECT,
+	GLADE_PROJECT_MODEL_COLUMN_MISC,
 	GLADE_PROJECT_MODEL_N_COLUMNS
 } GladeProjectModelColumns;
 
@@ -90,12 +91,14 @@ GType          glade_project_get_type            (void) G_GNUC_CONST;
 GladeProject  *glade_project_new                 (void);
 
 GladeProject  *glade_project_load                (const gchar  *path);
+gboolean       glade_project_load_from_file      (GladeProject *project, 
+						  const gchar  *path);
 
 gboolean       glade_project_save                (GladeProject *project, 
 						  const gchar   *path, 
 						  GError       **error);
-						 
-const gchar   *glade_project_get_path            (GladeProject *project);						 
+
+const gchar   *glade_project_get_path            (GladeProject *project);
 
 gchar         *glade_project_get_name            (GladeProject *project);
 
@@ -178,10 +181,6 @@ gchar         *glade_project_resource_fullpath    (GladeProject  *project,
 gboolean       glade_project_is_loading           (GladeProject *project);
  
 time_t         glade_project_get_file_mtime       (GladeProject *project);
-  
-guint          glade_project_get_instance_count   (GladeProject *project);
-
-void           glade_project_set_instance_count   (GladeProject *project, guint instance_count);
 
 gboolean       glade_project_get_modified         (GladeProject *project);
 
@@ -216,6 +215,14 @@ void          glade_project_update_signal_support_warning (GladeWidget  *widget,
 
 gchar        *glade_project_display_dependencies (GladeProject *project);
 
+void          glade_project_check_reordered (GladeProject       *project,
+					     GladeWidget        *parent,
+					     GList              *old_order);
+
+void          glade_project_push_progress (GladeProject *project);
+gboolean      glade_project_load_cancelled (GladeProject *project);
+void          glade_project_cancel_load (GladeProject *project);
+
 G_END_DECLS
 
 #endif /* __GLADE_PROJECT_H__ */
