@@ -18,6 +18,7 @@
  *
  * Authors:
  *   Chema Celorio <chema@celorio.com>
+ *   Tristan Van Berkom <tristan.van.berkom@gmail.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -291,27 +292,27 @@ glade_property_class_make_string_from_object (GladePropertyClass *property_class
 		GString       *str = g_string_sized_new (G_ASCII_DTOSTR_BUF_SIZE * 6 + 6);
 		gchar          buff[G_ASCII_DTOSTR_BUF_SIZE];
 
-		g_ascii_dtostr (buff, sizeof (buff), adj->value);
+		g_ascii_dtostr (buff, sizeof (buff), gtk_adjustment_get_value (adj));
 		g_string_append (str, buff);
 
 		g_string_append_c (str, ' ');
-		g_ascii_dtostr (buff, sizeof (buff), adj->lower);
+		g_ascii_dtostr (buff, sizeof (buff), gtk_adjustment_get_lower (adj));
 		g_string_append (str, buff);
 
 		g_string_append_c (str, ' ');
-		g_ascii_dtostr (buff, sizeof (buff), adj->upper);
+		g_ascii_dtostr (buff, sizeof (buff), gtk_adjustment_get_upper (adj));
 		g_string_append (str, buff);
 
 		g_string_append_c (str, ' ');
-		g_ascii_dtostr (buff, sizeof (buff), adj->step_increment);
+		g_ascii_dtostr (buff, sizeof (buff), gtk_adjustment_get_step_increment (adj));
 		g_string_append (str, buff);
 
 		g_string_append_c (str, ' ');
-		g_ascii_dtostr (buff, sizeof (buff), adj->page_increment);
+		g_ascii_dtostr (buff, sizeof (buff), gtk_adjustment_get_page_increment (adj));
 		g_string_append (str, buff);
 
 		g_string_append_c (str, ' ');
-		g_ascii_dtostr (buff, sizeof (buff), adj->page_size);
+		g_ascii_dtostr (buff, sizeof (buff), gtk_adjustment_get_page_size (adj));
 		g_string_append (str, buff);
 
 		string = g_string_free (str, FALSE);
@@ -611,7 +612,7 @@ glade_property_class_make_object_from_string (GladePropertyClass *property_class
 				icon = gtk_widget_render_icon (widget,
 							       GTK_STOCK_MISSING_IMAGE,
 							       GTK_ICON_SIZE_MENU, NULL);
-				gtk_object_sink (GTK_OBJECT (widget));
+				gtk_widget_destroy (widget);
 			}
 			
 			pixbuf = gdk_pixbuf_copy (icon);
@@ -673,7 +674,7 @@ glade_property_class_make_objects_from_string (GladePropertyClass *property_clas
 		}
 		g_strfreev (split);
 	}
-	return objects;
+	return g_list_reverse (objects);
 }
 
 /**
@@ -1487,12 +1488,18 @@ glade_property_class_update_from_node (GladeXmlNode        *node,
 		/* We overrode the pspec, now it *is* a virtual property. */
 		klass->virt              = TRUE;
 		
-		if (klass->tooltip) g_free (klass->tooltip);
-		if (klass->name)    g_free (klass->name);
-		
-		klass->tooltip = g_strdup (g_param_spec_get_blurb (klass->pspec));
-		klass->name    = g_strdup (g_param_spec_get_nick (klass->pspec));
-		
+		if (strcmp (g_param_spec_get_blurb (klass->pspec), "dummy") != 0)
+		{
+			g_free (klass->tooltip);
+			klass->tooltip = g_strdup (g_param_spec_get_blurb (klass->pspec));
+		}
+
+		if (klass->name == NULL || strcmp (g_param_spec_get_nick (klass->pspec), "dummy") != 0)
+		{
+			g_free (klass->name);
+			klass->name = g_strdup (g_param_spec_get_nick (klass->pspec));
+		}
+
 		if (klass->pspec->flags & G_PARAM_CONSTRUCT_ONLY)
 			klass->construct_only = TRUE;
 		
