@@ -111,8 +111,9 @@ glade_property_dup_impl (GladeProperty *template_prop, GladeWidget *widget)
 	else
 		g_value_copy (template_prop->value, property->value);
 
-	/* Need value in place here ... */
-	glade_property_set_enabled (property, template_prop->enabled);
+	property->enabled = template_prop->enabled;
+	property->state   = template_prop->state;
+
 	glade_property_set_sensitive (property, template_prop->sensitive,
 				      template_prop->insensitive_tooltip);
 	
@@ -129,7 +130,8 @@ glade_property_equals_value_impl (GladeProperty *property,
 	if (property->widget)
 	{
 		project = glade_widget_get_project (property->widget);
-		fmt     = glade_project_get_format (project);
+		if (project)
+			fmt = glade_project_get_format (project);
 	}
 
 	return !glade_property_class_compare (property->klass, property->value, value, fmt);
@@ -199,24 +201,21 @@ glade_property_update_prop_refs (GladeProperty *property,
 static gboolean
 glade_property_verify (GladeProperty *property, const GValue *value)
 {
-	if (property->klass->packing)
-	{
-		if (property->widget->parent)
-			return glade_widget_adaptor_child_verify_property (property->widget->parent->adaptor,
-									   property->widget->parent->object,
-									   property->widget->object,
-									   property->klass->id,
-									   value);
-		else
-			return FALSE;
-	}
-	else
-	{
-		return glade_widget_adaptor_verify_property (property->widget->adaptor, 
-							     property->widget->object,
-							     property->klass->id,
-							     value);
-	}
+	gboolean ret = FALSE;
+
+	if (property->klass->packing && property->widget->parent)
+		ret = glade_widget_adaptor_child_verify_property (property->widget->parent->adaptor,
+								  property->widget->parent->object,
+								  property->widget->object,
+								  property->klass->id,
+								  value);
+	else if (!property->klass->packing)
+		ret = glade_widget_adaptor_verify_property (property->widget->adaptor, 
+							    property->widget->object,
+							    property->klass->id,
+							    value);
+
+	return ret;
 }
 
 static void
@@ -248,7 +247,8 @@ glade_property_set_value_impl (GladeProperty *property, const GValue *value)
 #if 0
 	{
 		g_print ("***************************************************\n"); 
-		g_print ("Setting property %s on %s ..\n", 
+		g_print ("Setting %s property %s on %s ..\n", 
+			 property->klass->packing ? "packing" : "normal",
 			 property->klass->id,
 			 property->widget ? property->widget->name : "unknown");
 
@@ -291,11 +291,12 @@ glade_property_set_value_impl (GladeProperty *property, const GValue *value)
 	/* Add/Remove references from widget ref stacks here
 	 * (before assigning the value)
 	 */
-	if (property->widget && changed && glade_property_class_is_object 
-	    (property->klass, glade_project_get_format (project)))
+	if (property->widget && changed && 
+	    glade_property_class_is_object (property->klass, 
+					    project ? glade_project_get_format (project) : 
+					    GLADE_PROJECT_FORMAT_GTKBUILDER))
 		glade_property_update_prop_refs (property, property->value, value);
 
-
 	/* Make a copy of the old value */
 	g_value_init (&old_value, G_VALUE_TYPE (property->value));
 	g_value_copy (property->value, &old_value);
@@ -354,8 +355,8 @@ glade_property_sync_impl (GladeProperty *property)
 	 * (other properties may be used for convenience in the plugin).
 	 */
 	if ((property->klass->packing && 
-	     property != glade_widget_get_pack_property (property->widget, property->klass->id)) ||
-	    property != glade_widget_get_property (property->widget, property->klass->id))
+	     !glade_widget_get_pack_property (property->widget, property->klass->id)) ||
+	    !glade_widget_get_property (property->widget, property->klass->id))
 		return;
 
 	property->syncing++;
@@ -589,14 +590,14 @@ glade_property_klass_init (GladePropertyKlass *prop_class)
 		(object_class, PROP_I18N_TRANSLATABLE,
 		 g_param_spec_boolean 
 		 ("i18n-translatable", _("Translatable"), 
-		  _("Whether this property is translatable or not"),
+		  _("Whether this property is translatable"),
 		  TRUE, G_PARAM_READWRITE));
 
 	g_object_class_install_property 
 		(object_class, PROP_I18N_HAS_CONTEXT,
 		 g_param_spec_boolean 
 		 ("i18n-has-context", _("Has Context"), 
-		  _("Whether or not the translatable string has a context prefix"),
+		  _("Whether the translatable string has a context prefix"),
 		  FALSE, G_PARAM_READWRITE));
 
 	g_object_class_install_property 
