@@ -488,8 +488,8 @@ glade_xml_get_property_string_required (GladeXmlNode *node_in,
 gboolean
 glade_xml_get_property_version (GladeXmlNode *node_in, 
 				const gchar  *name, 
-				gint         *major, 
-				gint         *minor)
+				guint16      *major, 
+				guint16      *minor)
 {
 	xmlNodePtr node = (xmlNodePtr) node_in;
 	gchar *value = glade_xml_get_property_string (node_in, name);
@@ -758,6 +758,22 @@ glade_xml_context_get_doc (GladeXmlContext *context)
 	return context->doc;
 }
 
+gchar *
+glade_xml_dump_from_context (GladeXmlContext *context)
+{
+	GladeXmlDoc *doc;
+	xmlChar *string = NULL;
+	gchar *text;
+	int size;
+
+	doc = glade_xml_context_get_doc (context);
+	xmlDocDumpFormatMemory(&(doc->doc), &string, &size, 1);
+
+	text = claim_string (string);
+
+	return text;
+}
+
 gboolean
 glade_xml_node_is_comment (GladeXmlNode *node_in) 
 {
@@ -852,7 +868,7 @@ glade_xml_doc_save (GladeXmlDoc *doc_in, const gchar *full_path)
 	xmlDocPtr doc = (xmlDocPtr) doc_in;
 
 	xmlKeepBlanksDefault (0);
-	return xmlSaveFormatFile (full_path, doc, 1);
+	return xmlSaveFormatFileEnc (full_path, doc, "UTF-8", 1);
 }
 
 void
