@@ -33,6 +33,8 @@
 #include <gladeui/glade-popup.h>
 #include <gladeui/glade-inspector.h>
 
+#include <gladeui/glade-project.h>
+
 #include <string.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
@@ -50,8 +52,7 @@
 
 #define READONLY_INDICATOR (_("[Read Only]"))
 
-#define URL_USER_MANUAL      "http://glade.gnome.org/manual/index.html"
-#define URL_DEVELOPER_MANUAL "http://glade.gnome.org/docs/index.html"
+#define URL_DEVELOPER_MANUAL "http://library.gnome.org/devel/gladeui/"
 
 #define CONFIG_GROUP_WINDOWS        "Glade Windows"
 #define GLADE_WINDOW_DEFAULT_WIDTH  720
@@ -148,101 +149,6 @@ static void glade_window_config_save (GladeWindow *window);
 
 G_DEFINE_TYPE (GladeWindow, glade_window, GTK_TYPE_WINDOW)
 
-static void
-about_dialog_activate_link_func (GtkAboutDialog *dialog, const gchar *link, GladeWindow *window)
-{
-	GtkWidget *warning_dialog;
-	gboolean retval;
-	
-	retval = glade_util_url_show (link);
-	
-	if (!retval)
-	{
-		warning_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
-							 GTK_DIALOG_MODAL,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_OK,
-							 _("Could not display the URL '%s'"),
-							 link);
-						 
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (warning_dialog),
-							  _("No suitable web browser could be found."));
-						 	
-		gtk_window_set_title (GTK_WINDOW (warning_dialog), "");
-		
-		g_signal_connect_swapped (warning_dialog, "response",
-					  G_CALLBACK (gtk_widget_destroy),
-					  warning_dialog);
-				
-		gtk_widget_show (warning_dialog);
-	}	
-
-}
-
-/* locates the help file "glade.xml" with respect to current locale */
-static gchar*
-locate_help_file ()
-{
-	const gchar* const* locales = g_get_language_names ();
-
-	/* check if user manual has been installed, if not, GLADE_GNOMEHELPDIR is empty */
-	if (strlen (GLADE_GNOMEHELPDIR) == 0)
-		return NULL;
-
-	for (; *locales; locales++)
-	{
-		gchar *path;
-		
-		path = g_build_path (G_DIR_SEPARATOR_S, GLADE_GNOMEHELPDIR, "glade", *locales, "glade.xml", NULL);
-
-		if (g_file_test (path, G_FILE_TEST_EXISTS))
-		{
-			return (path);
-		}
-		g_free (path);
-	}
-	
-	return NULL;
-}
-
-static gboolean
-help_show (const gchar *link_id)
-{
-	gchar *file, *url, *command;
-	gboolean retval;
-	gint exit_status = -1;
-	GError *error = NULL; 	
-
-	file = locate_help_file ();
-	if (file == NULL)
-		return FALSE;
-
-	if (link_id != NULL) {
-		url = g_strconcat ("ghelp://", file, "?", link_id, NULL);
-	} else {
-		url = g_strconcat ("ghelp://", file, NULL);	
-	}
-
-	command = g_strconcat ("gnome-open ", url, NULL);
-			
-	retval = g_spawn_command_line_sync (command,
-					    NULL,
-					    NULL,
-					    &exit_status,
-					    &error);
-
-	if (!retval) {
-		g_error_free (error);
-		error = NULL;
-	}		
-	
-	g_free (command);
-	g_free (file);
-	g_free (url);
-	
-	return retval && !exit_status;
-}
-
 
 /* the following functions are taken from gedit-utils.c */
 
@@ -375,54 +281,6 @@ get_formatted_project_name_for_display (GladeProject *project, FormatNameFlags f
 	return pass3;
 }
 
-static gchar *
-replace_home_dir_with_tilde (const gchar *path)
-{
-#ifdef G_OS_UNIX
-	gchar *tmp;
-	gchar *home;
-
-	g_return_val_if_fail (path != NULL, NULL);
-
-	/* Note that g_get_home_dir returns a const string */
-	tmp = (gchar *) g_get_home_dir ();
-
-	if (tmp == NULL)
-		return g_strdup (path);
-
-	home = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
-	if (home == NULL)
-		return g_strdup (path);
-
-	if (strcmp (path, home) == 0)
-	{
-		g_free (home);
-		
-		return g_strdup ("~");
-	}
-
-	tmp = home;
-	home = g_strdup_printf ("%s/", tmp);
-	g_free (tmp);
-
-	if (g_str_has_prefix (path, home))
-	{
-		gchar *res;
-
-		res = g_strdup_printf ("~/%s", path + strlen (home));
-
-		g_free (home);
-		
-		return res;		
-	}
-
-	g_free (home);
-
-	return g_strdup (path);
-#else
-	return g_strdup (path);
-#endif
-}
 
 static void
 refresh_title (GladeWindow *window)
@@ -462,13 +320,13 @@ get_default_path (GladeWindow *window)
 }
 
 static void
-update_default_path (GladeWindow *window, GladeProject *project)
+update_default_path (GladeWindow *window, const gchar *filename)
 {
 	gchar *path;
 	
-	g_return_if_fail (glade_project_get_path (project) != NULL);
+	g_return_if_fail (filename != NULL);
 
-	path = g_path_get_dirname (glade_project_get_path (project));
+	path = g_path_get_dirname (filename);
 
 	g_free (window->priv->default_path);
 	window->priv->default_path = g_strdup (path);
@@ -647,7 +505,7 @@ format_project_list_item_tooltip (GladeProject *project)
 
 	if (glade_project_get_path (project))
 	{
-		path = replace_home_dir_with_tilde (glade_project_get_path (project));
+		path = glade_utils_replace_home_dir_with_tilde (glade_project_get_path (project));
 		
 		if (glade_project_get_readonly (project))
 		{
@@ -876,6 +734,7 @@ on_selector_button_toggled (GtkToggleToolButton *button, GladeWindow *window)
 		gtk_toggle_tool_button_set_active (window->priv->selector_button, TRUE);
 }
 
+
 static void
 on_drag_resize_button_toggled (GtkToggleToolButton *button, GladeWindow *window)
 {
@@ -1006,7 +865,7 @@ switch_to_project (GladeWindow *window, GladeProject *project)
 
 	/* increase project popularity */
 	recent_add (window, glade_project_get_path (project));
-	update_default_path (window, project);	
+	update_default_path (window, glade_project_get_path (project));	
 
 	for (i = 0; i < n; i++)
 	{
@@ -1168,6 +1027,22 @@ open_cb (GtkAction *action, GladeWindow *window)
 	g_free (path);
 }
 
+static gboolean
+check_loading_project_for_save (GladeProject *project)
+{
+	if (glade_project_is_loading (project))
+	{
+		gchar *name = glade_project_get_name (project);
+
+		glade_util_ui_message (glade_app_get_window(),
+				       GLADE_UI_INFO, NULL,
+				       _("Project %s is still loading."), name);
+		g_free (name);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 static void
 save (GladeWindow *window, GladeProject *project, const gchar *path)
 {
@@ -1178,6 +1053,9 @@ save (GladeWindow *window, GladeProject *project, const gchar *path)
 	GtkWidget *button;
 	gint       response;
 
+	if (check_loading_project_for_save (project))
+		return;
+
 	/* check for external modification to the project file */
 	mtime = glade_util_get_file_mtime (glade_project_get_path (project), NULL);
 	 
@@ -1236,13 +1114,11 @@ save (GladeWindow *window, GladeProject *project, const gchar *path)
 		return;
 	}
 	
-	glade_app_update_instance_count (project);
-
 	/* Get display_name here, it could have changed with "Save As..." */
 	display_name = glade_project_get_name (project);
 
 	recent_add (window, glade_project_get_path (project));
-	update_default_path (window, project);
+	update_default_path (window, glade_project_get_path (project));
 
 	/* refresh names */
 	refresh_title (window);
@@ -1271,6 +1147,9 @@ save_as (GladeWindow *window)
 	if (project == NULL)
 		return;
 
+	if (check_loading_project_for_save (project))
+		return;
+
 	filechooser = glade_util_file_dialog_new (_("Save As\342\200\246"), project,
 						  GTK_WINDOW (window),
 						  GLADE_FILE_DIALOG_ACTION_SAVE);
@@ -1500,9 +1379,18 @@ confirm_close_project (GladeWindow *window, GladeProject *project)
 }
 
 static void
-do_close (GladeWindow *window, GladeDesignView *view)
+do_close (GladeWindow *window, GladeProject *project)
 {
+	GladeDesignView *view;
 	gint n;
+
+	view = glade_design_view_get_from_project (project);
+
+	if (glade_project_is_loading (project))
+	{
+		glade_project_cancel_load (project);
+		return;
+	}
 	
 	n = gtk_notebook_page_num (GTK_NOTEBOOK (window->priv->notebook), GTK_WIDGET (view));
 	
@@ -1533,15 +1421,17 @@ close_cb (GtkAction *action, GladeWindow *window)
 			if (!close)
 				return;
 	}
-	do_close (window, view);
+	do_close (window, project);
 }
 
 static void
 quit_cb (GtkAction *action, GladeWindow *window)
 {
-	GList *list;
+	GList *list, *projects;
 
-	for (list = glade_app_get_projects (); list; list = list->next)
+	projects = g_list_copy (glade_app_get_projects ());
+
+	for (list = projects; list; list = list->next)
 	{
 		GladeProject *project = GLADE_PROJECT (list->data);
 
@@ -1549,20 +1439,24 @@ quit_cb (GtkAction *action, GladeWindow *window)
 		{
 			gboolean quit = confirm_close_project (window, project);
 			if (!quit)
+			{
+				g_list_free (projects);
 				return;
+			}
 		}
 	}
 
-	while (glade_app_get_projects ())
+	for (list = projects; list; list = list->next)
 	{
 		GladeProject *project = GLADE_PROJECT (glade_app_get_projects ()->data);
-		do_close (window, glade_design_view_get_from_project (project));
+		do_close (window, project);
 	}
 
 	glade_window_config_save (window);
 
-	gtk_main_quit ();
+	g_list_free (projects);
 
+	gtk_main_quit ();
 }
 
 static void
@@ -1653,9 +1547,9 @@ next_project_cb (GtkAction *action, GladeWindow *window)
 
 static void
 notebook_switch_page_cb (GtkNotebook *notebook,
-			     GtkNotebookPage *page,
-			     guint page_num,
-			     GladeWindow *window)
+			 GtkWidget *page,
+			 guint page_num,
+			 GladeWindow *window)
 {
 	GladeDesignView *view;
 	GladeProject *project;
@@ -1697,11 +1591,18 @@ notebook_switch_page_cb (GtkNotebook *notebook,
 	g_free (action_name);
 }
 
+static void
+set_widget_sensitive_on_load (GladeProject *project,
+			      GtkWidget    *widget)
+{
+	gtk_widget_set_sensitive (widget, TRUE);
+}
+
 static void
 notebook_tab_added_cb (GtkNotebook *notebook,
-			   GladeDesignView *view,
-			   guint page_num,
-			   GladeWindow *window)
+		       GladeDesignView *view,
+		       guint page_num,
+		       GladeWindow *window)
 {
 	GladeProject *project;
 	GtkWidget    *inspector;
@@ -1736,7 +1637,14 @@ notebook_tab_added_cb (GtkNotebook *notebook,
 	inspector = glade_inspector_new ();
 	gtk_widget_show (inspector);
 	glade_inspector_set_project (GLADE_INSPECTOR (inspector), project);
-		
+
+	if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (view), "view-added-while-loading")))
+	{
+		gtk_widget_set_sensitive (inspector, FALSE);
+		g_signal_connect (project, "parse-finished", 
+				  G_CALLBACK (set_widget_sensitive_on_load), inspector);
+	}
+
 	gtk_notebook_append_page (GTK_NOTEBOOK (window->priv->inspectors_notebook), inspector, NULL);
 	
 
@@ -1975,78 +1883,17 @@ toggle_tabs_cb (GtkAction *action, GladeWindow *window)
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (window->priv->notebook), FALSE);
 }
 
-static void
-show_help_cb (GtkAction *action, GladeWindow *window)
-{
-	GtkWidget *dialog;
-	gboolean retval;
-	
-	retval = help_show (NULL);
-	if (retval)
-		return;
-	
-	/* fallback to displaying online user manual */ 
-	retval = glade_util_url_show (URL_USER_MANUAL);	
-
-	if (!retval)
-	{
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_OK,
-						 _("Could not display the online user manual"));
-						 
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("No suitable web browser executable could be found "
-							    "to be executed and to display the URL: %s"),
-							    URL_USER_MANUAL);
-						 	
-		gtk_window_set_title (GTK_WINDOW (dialog), "");
-
-		g_signal_connect_swapped (dialog, "response",
-					  G_CALLBACK (gtk_widget_destroy),
-					  dialog);
-
-		gtk_widget_show (dialog);
-		
-	}
-}
-
 static void 
 show_developer_manual_cb (GtkAction *action, GladeWindow *window)
 {
-	GtkWidget *dialog;
-	gboolean retval;
-	
 	if (glade_util_have_devhelp ())
 	{
 		glade_util_search_devhelp ("gladeui", NULL, NULL);
 		return;	
 	}
-	
-	retval = glade_util_url_show (URL_DEVELOPER_MANUAL);	
 
-	if (!retval)
-	{
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_OK,
-						 _("Could not display the online developer reference manual"));
-						 
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("No suitable web browser executable could be found "
-							    "to be executed and to display the URL: %s"),
-							    URL_DEVELOPER_MANUAL);
-						 	
-		gtk_window_set_title (GTK_WINDOW (dialog), "");
-
-		g_signal_connect_swapped (dialog, "response",
-					  G_CALLBACK (gtk_widget_destroy),
-					  dialog);
-
-		gtk_widget_show (dialog);
-	}	
+	/* fallback to displaying online developer manual */
+	glade_util_url_show (URL_DEVELOPER_MANUAL);
 }
 
 static void 
@@ -2159,7 +2006,6 @@ static const gchar ui_info[] =
 "      <placeholder name='ProjectsListPlaceholder'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
-"      <menuitem action='HelpContents'/>"
 "      <menuitem action='DeveloperReference'/>"
 "      <separator/>"
 "      <menuitem action='About'/>"
@@ -2204,9 +2050,6 @@ static GtkActionEntry static_entries[] = {
 	{ "About", GTK_STOCK_ABOUT, NULL, NULL,
 	  N_("About this application"), G_CALLBACK (about_cb) },
 
-	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
-	  N_("Display the user manual"), G_CALLBACK (show_help_cb) },
-
 	{ "DeveloperReference", NULL, N_("_Developer Reference"), NULL,
 	  N_("Display the developer reference manual"), G_CALLBACK (show_developer_manual_cb) }
 };
@@ -2527,25 +2370,56 @@ static void
 tab_close_button_clicked_cb (GtkWidget    *close_button,
 			     GladeProject *project)
 {
-	GladeDesignView *view;
 	GladeWindow *window = GLADE_WINDOW (glade_app_get_window ());
 	gboolean close;
 
-	view = glade_design_view_get_from_project (project);
-
 	if (glade_project_get_modified (project))
 	{
 		close = confirm_close_project (window, project);
 			if (!close)
 				return;
 	}
-	do_close (window, view);
+	do_close (window, project);
+}
+
+static void
+project_load_progress_cb (GladeProject   *project,
+			  gint            total,
+			  gint            step,
+			  GtkProgressBar *progress)
+{
+	gchar  *name;
+
+	name = glade_project_get_name (project);
+
+	/* translators: "project name (objects loaded in total objects)" */
+	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progress), name);
+	g_free (name);
+				
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress), step * 1.0 / total);
+
+	while (gtk_events_pending ())
+		gtk_main_iteration ();
+}
+
+static void
+project_load_finished_cb (GladeProject   *project,
+			  GtkWidget      *tab_label)
+{
+	GtkWidget *progress, *label;
+
+	progress = g_object_get_data (G_OBJECT (tab_label), "tab-progress");
+	label    = g_object_get_data (G_OBJECT (tab_label), "tab-label");
+
+	gtk_widget_hide (progress);
+	gtk_widget_show (label);
 }
 
 static GtkWidget *
-create_notebook_tab (GladeWindow *window, GladeProject *project)
+create_notebook_tab (GladeWindow *window, GladeProject *project, gboolean for_file)
 {
 	GtkWidget *tab_label, *ebox, *hbox, *close_button, *label, *dummy_label;
+	GtkWidget *progress;
 
 	tab_label = gtk_hbox_new (FALSE, 4);
 	
@@ -2570,15 +2444,33 @@ create_notebook_tab (GladeWindow *window, GladeProject *project)
 	gtk_misc_set_padding (GTK_MISC (label), 0, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
+	progress = gtk_progress_bar_new ();
+	gtk_widget_add_events (progress,
+			       GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
+	gtk_widget_set_name (progress, "glade-tab-label-progress");
+	gtk_box_pack_start (GTK_BOX (hbox), progress, FALSE, FALSE, 0);
+	g_signal_connect (project, "load-progress", 
+			  G_CALLBACK (project_load_progress_cb), progress);
+
 	dummy_label = gtk_label_new ("");
 	gtk_box_pack_start (GTK_BOX (hbox), dummy_label, TRUE, TRUE, 0);
 
 	gtk_widget_show (ebox);
 	gtk_widget_show (hbox);
 	gtk_widget_show (close_button);
-	gtk_widget_show (label);
 	gtk_widget_show (dummy_label);
 
+	if (for_file)
+	{
+		gtk_widget_show (progress);
+
+		g_signal_connect (project, "parse-finished", 
+				  G_CALLBACK (project_load_finished_cb), tab_label);
+	}
+	else
+		gtk_widget_show (label);
+
+	g_object_set_data (G_OBJECT (tab_label), "tab-progress", progress);
 	g_object_set_data (G_OBJECT (tab_label), "tab-event-box", ebox);
 	g_object_set_data (G_OBJECT (tab_label), "tab-label", label);
 
@@ -2586,7 +2478,7 @@ create_notebook_tab (GladeWindow *window, GladeProject *project)
 }
 
 static void
-add_project (GladeWindow *window, GladeProject *project)
+add_project (GladeWindow *window, GladeProject *project, gboolean for_file)
 {
 	GtkWidget *view, *label;
 
@@ -2595,20 +2487,19 @@ add_project (GladeWindow *window, GladeProject *project)
  	view = glade_design_view_new (project);	
 	gtk_widget_show (view);
 
+	g_object_set_data (G_OBJECT (view), "view-added-while-loading", GINT_TO_POINTER (for_file));
+
 	/* Pass ownership of the project to the app */
 	glade_app_add_project (project);
 	g_object_unref (project);
 
 	/* Custom notebook tab label (will be refreshed later) */
-	label = create_notebook_tab (window, project);
+	label = create_notebook_tab (window, project, for_file);
 
 	gtk_notebook_append_page (GTK_NOTEBOOK (window->priv->notebook), GTK_WIDGET (view), label);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (window->priv->notebook), -1);	
 
 	refresh_notebook_tab_for_project (window, project);
-
-	/* Kick the inspector in the balls here... */
-	glade_project_selection_changed (project);
 }
 
 void
@@ -2626,7 +2517,7 @@ glade_window_new_project (GladeWindow *window)
 				       _("Could not create a new project."));
 		return;
 	}
-	add_project (window, project);
+	add_project (window, project, FALSE);
 }
 
 static gboolean
@@ -2634,30 +2525,30 @@ open_project (GladeWindow *window, const gchar *path)
 {
 	GladeProject *project;
 	
-	project = glade_project_load (path);
-	if (!project)
+	project = glade_project_new ();
+	
+	add_project (window, project, TRUE);
+	update_default_path (window, path);
+
+	if (!glade_project_load_from_file (project, path))
 	{
+		do_close (window, project);
+
 		recent_remove (window, path);
 		return FALSE;
 	}
-	
-	add_project (window, project);
 
 	/* increase project popularity */		
 	recent_add (window, glade_project_get_path (project));
-	update_default_path (window, project);
 	
 	return TRUE;
-
 }
 
 static void
 check_reload_project (GladeWindow *window, GladeProject *project)
 {
-	GladeDesignView *view;
-	gchar           *path;
-	gint             ret;
-	
+	gchar     *path;
+	gint       ret;
 	GtkWidget *dialog;
 	GtkWidget *button;
 	gint       response;
@@ -2726,10 +2617,9 @@ check_reload_project (GladeWindow *window, GladeProject *project)
 	}	
 		
 	/* Reopen */ 
-	view = glade_design_view_get_from_project (project);
 	path = g_strdup (glade_project_get_path (project));
 
-	do_close (window, view);
+	do_close (window, project);
 	ret = open_project (window, path);
 	g_free (path);
 }
@@ -2847,7 +2737,7 @@ refresh_undo_redo (GladeWindow *window)
 
 static void
 update_ui (GladeApp *app, GladeWindow *window)
-{      
+{
 	if (window->priv->active_view)
 		gtk_widget_queue_draw (GTK_WIDGET (window->priv->active_view));
 
@@ -3278,7 +3168,6 @@ glade_window_init (GladeWindow *window)
 	GtkWidget *widget;
 	GtkWidget *sep;
 	GtkAction *undo_action, *redo_action;
-	GtkAccelGroup *accel_group;	
 
 	window->priv = priv = GLADE_WINDOW_GET_PRIVATE (window);
 	
@@ -3344,6 +3233,7 @@ glade_window_init (GladeWindow *window)
 
 	/* notebook */
 	priv->notebook = gtk_notebook_new ();
+	gtk_notebook_set_scrollable (GTK_NOTEBOOK (priv->notebook), TRUE);
 
 	/* Show tabs (user preference) */
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->notebook), TRUE);
@@ -3410,7 +3300,7 @@ glade_window_init (GladeWindow *window)
 	gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbar), GTK_TOOL_ITEM (sep), -1);
 
 	priv->selector_button = 
-		GTK_TOGGLE_TOOL_BUTTON (create_selector_tool_button (GTK_TOOLBAR (priv->toolbar)));	
+		GTK_TOGGLE_TOOL_BUTTON (create_selector_tool_button (GTK_TOOLBAR (priv->toolbar)));
 	gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbar), 
 			    GTK_TOOL_ITEM (priv->selector_button), -1);
 
@@ -3472,15 +3362,8 @@ glade_window_init (GladeWindow *window)
 			  G_CALLBACK (clipboard_notify_handler_cb),
 			  window);
 
-	
-	gtk_about_dialog_set_url_hook ((GtkAboutDialogActivateLinkFunc) about_dialog_activate_link_func, window, NULL);
-
 	glade_app_set_window (GTK_WIDGET (window));
 
-	accel_group = gtk_ui_manager_get_accel_group(priv->ui);
-
-	gtk_window_add_accel_group (GTK_WINDOW (glade_app_get_clipboard_view ()), accel_group);
-
 	glade_window_config_load (window);
 
 #ifdef MAC_INTEGRATION
@@ -3512,6 +3395,18 @@ glade_window_class_init (GladeWindowClass *klass)
 	widget_class->configure_event    = glade_window_configure_event;
 	widget_class->window_state_event = glade_window_state_event;
 
+	gtk_rc_parse_string ("style \"short_progress\"\n"
+			     " { \n"
+			     "    GtkProgressBar::min-horizontal-bar-height = 1\n"
+			     "    GtkProgressBar::min-horizontal-bar-width = 1\n"
+			     "    GtkProgressBar::yspacing = 0\n"
+			     "    GtkProgressBar::xspacing = 4\n"
+			     "    xthickness = 0\n"
+			     "    ythickness = 0\n"
+			     " }\n"
+			     "\n"
+			     "widget \"*.glade-tab-label-progress\" style \"short_progress\"");
+
 	g_type_class_add_private (klass, sizeof (GladeWindowPrivate));
 }
 
